pyOpenair, a WKT 2 OpenAir converter
************************************

A simple package to convert geo data from `WKT <https://en.wikipedia.org/wiki/Well-known_text_representation_of_geometry>`_ to `OpenAir format <http://www.winpilot.com/usersguide/userairspace.asp>`_.

This project has been developped by LPO Auvergne-Rhône-Alpes to add `OpenAir <http://www.winpilot.com/UsersGuide/UserAirspace.asp>`_ export feature in `GeoTrek-admin <https://github.com/GeotrekCE/Geotrek-admin>`_ to sensitivity module for aerial areas.


Documentation
#############

`<https://pyopenair.readthedocs.io/en/latest/>`_

Installation
############

.. code:: console

    pip install pyopenair


Licence
#######

`GNU GPLv3 <https://www.gnu.org/licenses/gpl.html>`_

Team
####

* `@lpofredc <https://github.com/lpofredc/>`_ (`LPO Auvergne-Rhône-Alpes <https://github.com/lpoaura/>`_), main developper
* `@BPascal-91 <https://github.com/BPascal-91>`_ for advices, tests and recommendations


.. image:: https://raw.githubusercontent.com/lpoaura/biodivsport-widget/master/images/LPO_AuRA_l250px.png
    :align: center
    :height: 100px
    :alt: alternate text